@@ -1,5 +1,5 @@
 import requests
-
+from plumbum import colors
 from dict_tiny.setting import DEEPL_TRANS_API_BASE_URL
 
 
@@ -21,7 +21,13 @@ def deepl_trans(text, target_language=None):
             # print("DeepL error: ", resp_json["msg"])
             print("DeepL error, code: ", resp_json["code"])
         else:
-            for k, v in resp_json["data"].items():
+            print(colors.green | ">>> DeepL Translator")
+            res = {
+                "detected language": resp_json["data"]["detected_source_lang"],
+                "input": text,
+                "output": resp_json["data"]["text"]
+            }
+            for k, v in res.items():
                 print("{}: {}".format(k, v))
     except Exception as e:
         # print("DeepL error: ", str(e))
